# Changelog

## v0.9.0

- feat: new `Ollama` integration
- refactor: changed `OpenAILanguageModel` to `OpenAILikeLanguageModel` so it becomes easier to use with openai-compatible endpoints.
- feat: new parameter `base_url` in synapses and some `LanguageModel's` constructors.
